
public class Firma implements RadnaOrganizacija {

	private class Radnik {
		String id, ime;
		int plata;
		
		public Radnik(String id, String ime, int plata) {
			this.id = id;
			this.ime = ime;
			this.plata = plata;
		}
		
		public String toString() {
			return id + ", " + ime + ", " + plata;
		}
	}
	
	private int maxZaposlenih;
	private int brojZaposlenih;
	private Radnik[] radnici;
	
	public Firma(int maxZaposlenih) {
		this.maxZaposlenih = maxZaposlenih;
		brojZaposlenih = 0;
		radnici = new Radnik[maxZaposlenih];
	}
	
	private int pretrazi(String id) {
		for (int i = 0; i < brojZaposlenih; i++) {
			if (radnici[i].id.equals(id)) {
				return i;
			}
		}
		
		return -1;
	}
	
	public void zaposli(String id, String ime, int plata) 
		throws RadnaOrganizacijaException 
	{
		if (brojZaposlenih == maxZaposlenih) {
			throw new RadnaOrganizacijaException(
				RadnaOrganizacijaException.TipGreske.ZAPOSLJAVANJE,
				"Firma vec ima maksimalan dozvoljen broj radnika"
			);
		}
		
		if (pretrazi(id) != -1) {
			throw new RadnaOrganizacijaException(
				RadnaOrganizacijaException.TipGreske.ZAPOSLJAVANJE,
				"Radnik sa identifikatorom " + id + " vec postoji"
			);
		}
		
		radnici[brojZaposlenih++] = new Radnik(id, ime, plata);
	}

	public void otpusti(String id) 
		throws RadnaOrganizacijaException 
	{
		if (brojZaposlenih == 0) {
			throw new RadnaOrganizacijaException(
				RadnaOrganizacijaException.TipGreske.OTPUSTANJE,
				"Firma nema zaposlenih"
			);
		}
		
		int pozicija = pretrazi(id);
		if (pozicija == -1) {
			throw new RadnaOrganizacijaException(
				RadnaOrganizacijaException.TipGreske.OTPUSTANJE,
				"Radnik sa identifikatorom " + id + " ne postoji"
			);
		}
		
		for (int i = pozicija; i < brojZaposlenih - 1; i++) {
			radnici[i] = radnici[i + 1];
		}
		--brojZaposlenih;
	}
	
	public void stampajSve() {
		System.out.println("Zaposleni u radnoj organizaciji: ");
		for (int i = 0; i < brojZaposlenih; i++) {
			System.out.println(radnici[i]);
		}
	}
}
